from setuptools import setup

setup(
	name="asterisk_dialplan",
	version="0.1.1",
	author="Andrew Yager",
	author_email="andrew@rwts.com.au",
	license="BSD",
	packages=['asterisk_dialplan'],
	description="Helpers to convert numbers to dialplan strings for use in Asterisk",
	classifiers=[
		"Development Status :: 4 - Beta",
		"Topic :: Communications :: Telephony",
		"Topic :: Software Development :: Libraries",
		"License :: OSI Approved :: BSD License",
		]
)
